@@ -32,10 +32,9 @@ class SignalBase():
 
 
         self.__chercher_nom_valide(nom)
-        if len(vecteur_signal):
+        if len(vecteur_signal) > 0:
             self.vecteur_signal = vecteur_signal
         else:
-            print(self.base_de_temps.N)
             self.vecteur_signal = np.zeros(self.base_de_temps.N)
 
         if base_de_temps.N != len(self.vecteur_signal):
@@ -47,7 +46,6 @@ class SignalBase():
         sortie.mesures = Mesures()
         sortie.voie = Voie()
         sortie.trigger = Trigger()
-        sortie.liste_signaux.append(sortie)
         if nom != "":
             sortie.nom = nom + "_copié"
         return sortie
