@@ -18,14 +18,17 @@ from signaux.signal_sysam import Sysam
 import base.utiles_base as utb
 
 class Sysam1Base():
-    def __init__(self, liste_signaux):
+    def __init__(self, liste_signaux, affichage):
         self.sysam = pycan.Sysam("SP5")
+        self.affichage = affichage
+
         if isinstance(liste_signaux, list) and len(liste_signaux)> 0:
             self.liste_signaux = liste_signaux
         else:
             print("Pas de signaux")
             sys.exit()
-        utb.print_liste(self.liste_signaux)
+        if affichage:  
+            utb.print_liste(self.liste_signaux)
 
         self.liste_entrees_simples = utb.lister_test(self.liste_signaux, 
             lambda s: s.voie.tester_entree_simple(),
@@ -73,39 +76,39 @@ class Sysam1Base():
         return self
 
     def __exit__(self, *args, **kwargs):
-        # self.voie.stopper_sorties(1, 1)
         # self.voie.close()
         pass
 
     def __del__(self):
-        self.sysam.close()
+        self.sysam.stopper_sorties(1, 1)
+        self.sysam.fermer()
     
-
 if __name__ == "__main__":
 
-    liste_tmin_tmax = [0, 2e-3]
-    Te = 1e-4
+    # liste_tmin_tmax = [0, 2e-3]
+    # Te = 1e-4
 
-    N = 6
-    liste_signaux = []
-    for i in range(N):
-        liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+    # N = 6
+    # liste_signaux = []
+    # for i in range(N):
+    #     liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
 
-    liste_signaux[0].configurer_voie("SA1", repetition = True)
-    liste_signaux[1].configurer_voie("SA2", repetition = True)
+    # liste_signaux[0].configurer_voie("SA1", repetition = True)
+    # liste_signaux[1].configurer_voie("SA2", repetition = True)
     
-    # s1.configurer_trigger(0.)
-    sysam = Sysam1Base(liste_signaux)
-    del(sysam)
+    # # s1.configurer_trigger(0.)
+    # sysam = Sysam1Base(liste_signaux)
+    # del(sysam)
 
-    liste_signaux[2].configurer_voie("EA1", repetition = True)
-    liste_signaux[3].configurer_voie("DIFF2", repetition = True)
+    # liste_signaux[2].configurer_voie("EA1", repetition = True)
+    # liste_signaux[3].configurer_voie("DIFF2", repetition = True)
 
-    sysam = Sysam1Base(liste_signaux)
-    del(sysam)
+    # sysam = Sysam1Base(liste_signaux)
+    # del(sysam)
     
-    liste_signaux[2].configurer_trigger(0.)
-    sysam = Sysam1Base(liste_signaux)
-    del(sysam)
-
+    # liste_signaux[2].configurer_trigger(0.)
+    # sysam = Sysam1Base(liste_signaux)
+    # del(sysam)
 
+    sysam = pycan.Sysam("SP5")
+    sysam.fermer()
