@@ -22,8 +22,8 @@ import base.utiles_base as utb
 
 
 class Sysam3Test(Sysam2Mode):
-    def __init__(self, liste_signaux):
-        Sysam2Mode.__init__(self, liste_signaux)
+    def __init__(self, liste_signaux, affichage):
+        Sysam2Mode.__init__(self, liste_signaux, affichage)
         if self.tester_liste_signaux():
             self.test_signaux = True
         else:
