@@ -11,12 +11,14 @@ except:
     # print(" -> Fonctionnement en mode émulation")
     import acquisition.emulateur_sysam_sp5 as pycan
 
+from signaux.signal_base import SignalBase
 from signaux.signal_gbf import GBF
 from signaux.signal_fourier import Fourier
 from signaux.signal_sysam import Sysam
 
 import base.temps_base
 import base.voie_base
+import base.utiles_base as utb
 
 import signaux
 
@@ -25,8 +27,20 @@ from sysam.sysam_4_methodes import Sysam4Methodes
 __all__ = ["demarrer_sysam"]
 
  
-def demarrer_sysam(liste_signaux=None):
-    with SysamSP5(liste_signaux) as sysam:
+def demarrer_sysam(*args, **kwargs):
+    args = list(args)
+    liste_signaux = []
+    test_signal = len(args) > 0 and isinstance(args[0], SignalBase)
+    if not test_signal:
+        print("Quels sont les signaux gérés par sysam?")
+        return
+    s = args[0]
+    while test_signal:
+        liste_signaux.append(utb.analyser_args(args, " ", lambda x: isinstance(x, SignalBase), s)[0])
+        test_signal = len(args) > 0 and isinstance(args[0], SignalBase)
+    affichage = utb.analyser_args_kwargs(args, kwargs, "affichage", lambda x: isinstance(x, bool), True)
+
+    with SysamSP5(liste_signaux, affichage) as sysam:
         pass
 
 # def demarrer_sysam(liste_signaux=None):
@@ -41,8 +55,8 @@ def demarrer_sysam(liste_signaux=None):
 #                 os._sys.exit(0)
 
 class SysamSP5(Sysam4Methodes):
-    def __init__(self, liste_signaux):
-        Sysam4Methodes.__init__(self, liste_signaux)
+    def __init__(self, liste_signaux, affichage):
+        Sysam4Methodes.__init__(self, liste_signaux, affichage)
 
         if "entree" in self.chaine_mode:
             self.sysam.config_entrees(*self.calculer_arguments_config_entrees())
@@ -50,9 +64,7 @@ class SysamSP5(Sysam4Methodes):
 
         if "trigger" in self.chaine_mode:
             self.sysam.config_trigger(*self.calculer_arguments_config_trigger())
-        else:
-            self.sysam.desactiver_trigger()
-
+ 
         if "sortie1" in self.chaine_mode and "synchrone" not in self.chaine_mode:
             self.sysam.config_sortie(*self.calculer_arguments_config_sortie(1))
 
@@ -86,12 +98,12 @@ class SysamSP5(Sysam4Methodes):
         temps = self.sysam.temps()
         entrees = self.sysam.entrees()
         voies = self.calculer_arguments_config_entrees()[0]
-
+        # print("mettre a jour entrees ", self.chaine_mode)
         if "synchrone" not in self.chaine_mode:
             Nsysam = np.max(base.temps_base.BaseTemps.liste_bases_de_temps_sysam) + 1
             base.temps_base.BaseTemps.liste_bases_de_temps_sysam.append(Nsysam)
         else:
-            Nsysam = None
+            Nsysam = 0
 
         for s in self.liste_entrees:
             voie = s.voie.calculer_numero()
@@ -101,37 +113,68 @@ class SysamSP5(Sysam4Methodes):
             s.base_de_temps.Nsysam = Nsysam
 
 if __name__ == "__main__":
-    liste_tmin_tmax = [0, 2e-3]
-    Te = 1e-4
+    # def faire_une_mesure(f, Ue, tau, n_periodes):
+    #     T = 1/f
+    #     Te = max(T/100, 2e-7)
+    #     s = GBF("cosinus", F = f, liste_tmin_tmax = [0, T], Te = Te)    
+    #     s.configurer_voie("SA1", repetition = True)
+    #     print("se")
+    #     se = Sysam("EA0", liste_tmin_tmax = [tau, tau + n_periodes*T], Te = Te)
+    #     print("ss")
+    #     ss = Sysam("EA1", liste_tmin_tmax = [tau, tau + n_periodes*T], Te = Te)
+    #     se.configurer_trigger(0)
+    #     sysam = SysamSP5([s, se, ss])
 
-    N = 10
-    liste_signaux = []
-    for i in range(N):
-        liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+    #     Vppe = se.mesurer_Vpp()
+    #     Vpps = ss.mesurer_Vpp()
+    #     G = Vpps / Vppe
+    #     phi = ss.mesurer_dephasage_par_rapport_a(se)
+    #     Sysam.tracer_signaux([se, ss])
+    #     return G, phi
 
-    # # tester acquisition non synchrone
-    # liste_signaux[0].configurer_voie("EA1")
-    # liste_signaux[1].configurer_voie("SA1")
-    # liste_signaux[2].configurer_voie("DIFF2")
+    # def tracer_bode(liste_fmin_fmax, n_points, Ue, tau, n_periodes):
+    #     fmin, fmax = liste_fmin_fmax
+    #     vecteur_f = np.logspace(np.log10(fmin), np.log10(fmax), n_points)
+    #     vecteur_G = np.zeros(n_points)
+    #     vecteur_phi = np.zeros(n_points)
+        
+    #     for i in range(len(vecteur_f)):
+    #         f = vecteur_f[i]
+    #         G, phi =  faire_une_mesure(f, Ue, tau, n_periodes)
+    #         print("f = {0} ; G = {1} ; phi = {2} rad".format(f, G, phi))
+    #         vecteur_G[i], vecteur_phi[i] = G, phi
+    #     plt.subplot(121)   
+    #     plt.semilogx(vecteur_f, 20*np.log10(vecteur_G))
+    #     plt.subplot(122)   
+    #     plt.semilogx(vecteur_f, vecteur_phi)
+    #     plt.show()
 
-    # liste_signaux[2].configurer_trigger(0)
-    # sysam = SysamSP5(liste_signaux)
+    # # tracer_bode([50, 80000], 10, 9, 1e-1, 30)
+    # Ts2 = 0.01
+    # F = 1/Ts2/2
+    # ss = GBF("carre", F = F, liste_tmin_tmax = [0, 1/F], Te = 1e-4)
+    # ss.configurer_voie("SA1", repetition = False)
+    # sss = Sysam("EA0", liste_tmin_tmax = [0.001, 3*Ts2], Te = 1e-4)
+    # ssss = Sysam("EA1", liste_tmin_tmax = [0.001, 3*Ts2], Te = 1e-4)
+    # demarrer_sysam([ss, sss, ssss])
+    
+    # print(ss.base_de_temps.Nsysam)
+    # print(sss.base_de_temps.Nsysam)
+    # print(ssss.base_de_temps.Nsysam)
 
-    # GBF.tracer_signaux(liste_signaux[0:3:2])
+    # Sysam.tracer_signaux([sss,ssss], superposition = False)
+    T1 = 1e-3
+    sortie1 = GBF(F = 1/T1, liste_tmin_tmax = [0, T1], Te = 2e-7)
+    sortie1.configurer_voie("SA1", repetition = True)
 
-    # # tester acquisition synchrone
-    # liste_signaux[0].configurer_voie("EA1")
-    # liste_signaux[1].configurer_voie("SA1")
-    # liste_signaux[2].configurer_voie("DIFF2")
+    entree1 = Sysam("DIFF3", liste_tmin_tmax = [0, 5*T1], Te = 1e-7)
+    entree1.configurer_trigger(0)
 
-    # sysam = SysamSP5(liste_signaux)
+    T2 = 2.5e-3
+    sortie2 = GBF(F = 1/T2, liste_tmin_tmax = [0, T2], Te = 7e-7)
+    sortie2.configurer_voie("SA2", repetition = True)
 
-    # GBF.tracer_signaux(liste_signaux[0:3])
-
-    # tester acquisition sans entrées
-    liste_signaux[0].configurer_voie("EA1")
-    liste_signaux[1].configurer_voie("DIFF2")
-
-    sysam = SysamSP5(liste_signaux)
-
-    GBF.tracer_signaux(liste_signaux[0:2])
+    entree2 = Sysam("EA2", liste_tmin_tmax = [0, 5*T1], Te = 1e-7)
+    
+    demarrer_sysam(entree1, sortie1, entree2, sortie2, True)
+    GBF.tracer_signaux(sortie2, entree1, entree2, titre = "zoo")
\ No newline at end of file
